@@ -1,10 +1,16 @@
 import logging
 
 from .boto3_proxy import SessionProxy  # noqa: F401
+from .hook import Hook  # noqa: F401
 from .interface import (  # noqa: F401
     Action,
+    BaseHookHandlerRequest,
     BaseResourceHandlerRequest,
     HandlerErrorCode,
+    HookContext,
+    HookInvocationPoint,
+    HookProgressEvent,
+    HookStatus,
     OperationStatus,
     ProgressEvent,
 )
