@@ -1,11 +1,11 @@
 import datetime
 import logging
-from typing import Any, List, Mapping, Optional
+from typing import Any, List, Mapping, Optional, Union
 
 from botocore.exceptions import ClientError  # type: ignore
 
 from .boto3_proxy import SessionProxy
-from .interface import Action, MetricTypes, StandardUnit
+from .interface import Action, HookInvocationPoint, MetricTypes, StandardUnit
 
 LOG = logging.getLogger(__name__)
 
@@ -134,6 +134,91 @@ class MetricsPublisher:
         return f"{METRIC_NAMESPACE_ROOT}/{suffix}"
 
 
+class HookMetricsPublisher(MetricsPublisher):
+    def __init__(self, session: SessionProxy, hook_type: str, account_id: str) -> None:
+        super().__init__(session, hook_type)
+        self._hook_type = hook_type
+        self._account_id = account_id
+        self._namespace = self._make_hook_namespace(hook_type, account_id)
+
+    # pylint: disable=arguments-differ
+    def publish_exception_metric(  # type: ignore
+        self,
+        timestamp: datetime.datetime,
+        invocation_point: HookInvocationPoint,
+        error: Any,
+    ) -> None:
+        dimensions: Mapping[str, str] = {
+            "DimensionKeyInvocationPointType": invocation_point.name,
+            "DimensionKeyExceptionType": str(type(error)),
+            "DimensionKeyHookType": self._hook_type,
+        }
+        self.publish_metric(
+            metric_name=MetricTypes.HandlerException,
+            dimensions=dimensions,
+            unit=StandardUnit.Count,
+            value=1.0,
+            timestamp=timestamp,
+        )
+
+    # pylint: disable=arguments-differ
+    def publish_invocation_metric(  # type: ignore
+        self, timestamp: datetime.datetime, invocation_point: HookInvocationPoint
+    ) -> None:
+        dimensions = {
+            "DimensionKeyInvocationPointType": invocation_point.name,
+            "DimensionKeyHookType": self._hook_type,
+        }
+        self.publish_metric(
+            metric_name=MetricTypes.HandlerInvocationCount,
+            dimensions=dimensions,
+            unit=StandardUnit.Count,
+            value=1.0,
+            timestamp=timestamp,
+        )
+
+    # pylint: disable=arguments-differ
+    def publish_duration_metric(  # type: ignore
+        self,
+        timestamp: datetime.datetime,
+        invocation_point: HookInvocationPoint,
+        milliseconds: float,
+    ) -> None:
+        dimensions = {
+            "DimensionKeyInvocationPointType": invocation_point.name,
+            "DimensionKeyHookType": self._hook_type,
+        }
+
+        self.publish_metric(
+            metric_name=MetricTypes.HandlerInvocationDuration,
+            dimensions=dimensions,
+            unit=StandardUnit.Milliseconds,
+            value=milliseconds,
+            timestamp=timestamp,
+        )
+
+    def publish_log_delivery_exception_metric(
+        self, timestamp: datetime.datetime, error: Any
+    ) -> None:
+        dimensions = {
+            "DimensionKeyInvocationPointType": "ProviderLogDelivery",
+            "DimensionKeyExceptionType": str(type(error)),
+            "DimensionKeyHookType": self._hook_type,
+        }
+        self.publish_metric(
+            metric_name=MetricTypes.HandlerException,
+            dimensions=dimensions,
+            unit=StandardUnit.Count,
+            value=1.0,
+            timestamp=timestamp,
+        )
+
+    @staticmethod
+    def _make_hook_namespace(hook_type: str, account_id: str) -> str:
+        suffix = hook_type.replace("::", "/")
+        return f"{METRIC_NAMESPACE_ROOT}/{account_id}/{suffix}"
+
+
 class MetricsPublisherProxy:
     """A proxy for publishing metrics to multiple publishers. \
     Iterates over available publishers and publishes.
@@ -164,23 +249,42 @@ class MetricsPublisherProxy:
             publisher = MetricsPublisher(session, type_name)
             self._publishers.append(publisher)
 
+    def add_hook_metrics_publisher(
+        self,
+        session: Optional[SessionProxy],
+        type_name: Optional[str],
+        account_id: Optional[str],
+    ) -> None:
+        if session and type_name and account_id:
+            publisher = HookMetricsPublisher(session, type_name, account_id)
+            self._publishers.append(publisher)
+
     def publish_exception_metric(
-        self, timestamp: datetime.datetime, action: Action, error: Any
+        self,
+        timestamp: datetime.datetime,
+        action: Union[Action, HookInvocationPoint],
+        error: Any,
     ) -> None:
         for publisher in self._publishers:
-            publisher.publish_exception_metric(timestamp, action, error)
+            publisher.publish_exception_metric(timestamp, action, error)  # type: ignore
 
     def publish_invocation_metric(
-        self, timestamp: datetime.datetime, action: Action
+        self, timestamp: datetime.datetime, action: Union[Action, HookInvocationPoint]
     ) -> None:
         for publisher in self._publishers:
-            publisher.publish_invocation_metric(timestamp, action)
+            publisher.publish_invocation_metric(timestamp, action)  # type: ignore
 
+    # pylint: disable=line-too-long
     def publish_duration_metric(
-        self, timestamp: datetime.datetime, action: Action, milliseconds: float
+        self,
+        timestamp: datetime.datetime,
+        action: Union[Action, HookInvocationPoint],
+        milliseconds: float,
     ) -> None:
+        # fmt off
         for publisher in self._publishers:
-            publisher.publish_duration_metric(timestamp, action, milliseconds)
+            publisher.publish_duration_metric(timestamp, action, milliseconds)  # type: ignore
+        # fmt on
 
     def publish_log_delivery_exception_metric(
         self, timestamp: datetime.datetime, error: Any
